
#include <stdio.h>
#include <stdlib.h>
#include <sys/times.h>

#define LINUX    1
#define SOLARIS  0
#define FREEBSD  0
#define ALPHA    0  /* Tru64 UNIX */

#if LINUX
# include <unistd.h>
# include <sys/sysinfo.h>
#elif SOLARIS
#include <unistd.h>
#elif FREEBSD || NETBSD
# include <sys/types.h>
# include <sys/sysctl.h>
#elif ALPHA
# include <sys/sysinfo.h>
#endif


int main(int argc, char *argv[])
{
  unsigned int n_procs, phys_mem;

#if LINUX
   phys_mem = sysconf(_SC_PAGE_SIZE) * sysconf(_SC_PHYS_PAGES);
   n_procs = get_nprocs_conf();
#elif SOLARIS
   phys_mem = sysconf(_SC_PAGE_SIZE) * sysconf(_SC_PHYS_PAGES);
   n_procs = sysconf(_SC_NPROCESSORS_CONF);
#elif FREEBSD || NETBSD
  int mib[2];
  size_t len = sizeof(unsigned int);

  mib[0] = CTL_HW;
  mib[1] = HW_NCPU;
  sysctl(mib, 2, &n_procs, &len, NULL, 0);
  mib[1] = HW_PHYSMEM;
  sysctl(mib, 2, &phys_mem, &len, NULL, 0);
#elif ALPHA
   long pm;
   getsysinfo(GSI_PHYSMEM, (char *)&pm, sizeof(pm), NULL,NULL,NULL);
   phys_mem = (int)pm * 1024; 
   getsysinfo(GSI_CPUS_IN_BOX, (char *)&n_procs, sizeof(n_procs), NULL,NULL,NULL);
#endif

  printf("n_procs=%u, phys_mem=%u (%u MiB)\n",
     n_procs, phys_mem, phys_mem/(1024*1024));

#define FWD  1
#define REV  0

   phys_mem = 0;
   printf("\n %d == 1 -> %d, %d == 0 -> %d\n", 
	  phys_mem, phys_mem == 1, phys_mem, phys_mem == 0);

   phys_mem = 1;
   printf(" %d == 1 -> %d, %d == 0 -> %d\n", 
	  phys_mem, phys_mem == 1, phys_mem, phys_mem == 0);

   } 
